@@ -1,3 +1,13 @@
+/*! \file
+Copyright (c) 2003, The Regents of the University of California, through
+Lawrence Berkeley National Laboratory (subject to receipt of any required 
+approvals from U.S. Dept. of Energy) 
+
+All rights reserved. 
+
+The source code is distributed under BSD license, see the file License.txt
+at the top-level directory.
+*/
 
 /*! @file 
  * \brief 
@@ -21,7 +31,7 @@
  */
 
 void
-zreadtriple(FILE *fp, int_t *m, int_t *n, int_t *nonz,
+zreadtriple_dist(FILE *fp, int_t *m, int_t *n, int_t *nonz,
 	    doublecomplex **nzval, int_t **rowind, int_t **colptr)
 {
     int_t    j, k, jsize, nnz, nz, new_nonz;
@@ -47,7 +57,7 @@ zreadtriple(FILE *fp, int_t *m, int_t *n, int_t *nonz,
     new_nonz = *nonz;
 #endif
     *m = *n;
-    printf("m %ld, n %ld, nonz %ld\n", (long long) *m, (long long) *n, (long long) *nonz);
+    printf("m %lld, n %lld, nonz %lld\n", (long long) *m, (long long) *n, (long long) *nonz);
     zallocateA_dist(*n, new_nonz, nzval, rowind, colptr); /* Allocate storage */
     a    = *nzval;
     asub = *rowind;
